==> haskell-ansi-terminal-0.6.3.1-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-ansi-terminal.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ansi-terminal
version: 0.6.3.1
id: ansi-terminal-0.6.3.1-59sjf9WqHYuFAo9gQw9Bhp
key: ansi-terminal-0.6.3.1-59sjf9WqHYuFAo9gQw9Bhp
license: BSD3
maintainer: Roman Cheplyaka <roma@ro-che.info>
homepage: https://github.com/feuerbach/ansi-terminal
synopsis: Simple ANSI terminal support, with Windows compatibility
description:
    ANSI terminal support for Haskell: allows cursor movement, screen clearing, color output showing or hiding the cursor, and
    changing the title. Compatible with Windows and those Unixes with ANSI terminals, but only GHC is supported as a compiler.
category: User Interfaces
author: Max Bolingbroke
exposed: True
exposed-modules:
    System.Console.ANSI System.Console.ANSI.Types
    System.Console.ANSI.Codes
hidden-modules: System.Console.ANSI.Unix
abi: fa8c135351189eed22940497715ee4ee
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/ansi-terminal-0.6.3.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/ansi-terminal-0.6.3.1
dynamic-library-dirs: /usr/lib/arm-linux-ghc-8.0.2
data-dir: /usr/share/arm-linux-ghc-8.0.2/ansi-terminal-0.6.3.1
hs-libraries: HSansi-terminal-0.6.3.1-59sjf9WqHYuFAo9gQw9Bhp
depends:
    base-4.9.1.0
haddock-interfaces: /usr/share/doc/haskell-ansi-terminal/html/ansi-terminal.haddock
haddock-html: /usr/share/doc/haskell-ansi-terminal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ansi-terminal-0.6.3.1-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-ansi-terminal.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ansi-terminal
version: 0.6.3.1
id: ansi-terminal-0.6.3.1-BIEgiaci8VQ7yyITu4jhfU
key: ansi-terminal-0.6.3.1-BIEgiaci8VQ7yyITu4jhfU
license: BSD3
maintainer: Roman Cheplyaka <roma@ro-che.info>
homepage: https://github.com/feuerbach/ansi-terminal
synopsis: Simple ANSI terminal support, with Windows compatibility
description:
    ANSI terminal support for Haskell: allows cursor movement, screen clearing, color output showing or hiding the cursor, and
    changing the title. Compatible with Windows and those Unixes with ANSI terminals, but only GHC is supported as a compiler.
category: User Interfaces
author: Max Bolingbroke
exposed: True
indefinite: False
exposed-modules:
    System.Console.ANSI System.Console.ANSI.Codes
    System.Console.ANSI.Types
hidden-modules: System.Console.ANSI.Unix
abi: 8d42c7012ae6bb1dfca5905fe8a25762
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/ansi-terminal-0.6.3.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/ansi-terminal-0.6.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/ansi-terminal-0.6.3.1
hs-libraries: HSansi-terminal-0.6.3.1-BIEgiaci8VQ7yyITu4jhfU
depends:
    base-4.10.0.0
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
haddock-interfaces: /usr/share/doc/haskell-ansi-terminal/html/ansi-terminal.haddock
haddock-html: /usr/share/doc/haskell-ansi-terminal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
